GOOF----LE-4-2.0S      ]  4    h      ] g  guile	 	g  define-module*	 	 	g  gnucash	g  price-quotes	 		g  filenameS	
f  price-quotes.scm	g  set-current-module	 	
 	g  call-with-deferred-observers	 	 	g  module-export!	 	 	g  current-module	 	 	g  gnc:book-add-quotes	 	g   gnc:price-quotes-install-sources	 	g  process-use-modules	 	 	g  main	 	  	!g  
gnc-module	"! 	#" 	$g  
core-utils	%$ 	&% 	'g  srfi	(g  srfi-1	)'( 	*) 	+g  gnc:module-load	,f  gnucash/gnome-utils	-f  gnucash/app-utils	.g  for-each	/g  item-list->hash!	0g  
string-append	1g  gnc-path-get-bindir	2f  
/gnc-fq-check	3g  gnc:*finance-quote-check*	4g  string-null?	5g  gnc-spawn-process-async	6f  perl	7f  -w	8g  gnc-detach-process	9g  fdes->inport	:g  gnc-process-get-fd	;g  catch	<g  read	=g  	gnc:debug	>f  	results: 	?g  gnc:fq-check-sources	@f  /gnc-fq-helper	Ag  gnc:*finance-quote-helper*	Bg  
fdes->outport	Cg  map	Df  handling-request: 	Eg  display	Ff   	Gg  write	Hg  newline	Ig  force-output	Jg  gnc:fq-get-quotes	Kg  gnc-commodity-table-get-table	Lg  ,gnc-commodity-table-get-quotable-commodities	Mg  filter	Ng  gnc-commodity-equiv	Og  
partition!	Pg  string=?	Qf  currency	Rg  make-hash-table	Sg  car	Tg  cdr	Ug  hash-ref	Vg  	hash-set!	Wg  append	Xg  	hash-fold	Yg  gnc-commodity-get-mnemonic	Zg  every	[g  failed-conversion	\g  length	]f  call-data-item: 	^f  result-subitem: 	_g  reverse	`g  
filter-map	ag  gnc-commodity-get-namespace	bf  :	cg  gnucash-ui-is-running	dg  gnc-error-dialog	eg  _	ff  *No commodities marked for quote retrieval.	gg  gnc:warn	hf  -Unable to get quotes or diagnose the problem.	ig  member	jg  missing-lib	kf  XYou are missing some needed Perl libraries.
Run 'gnc-fq-update' as root to install them.	lf  
	mg  system-error	nf  ;There was a system error while retrieving the price quotes.	og  call-with-output-string	pf  *Unable to retrieve quotes for these items:	qf    	rg  string-join	sf  
  	tg  gnc-verify-dialog	uf  $Continue using only the good quotes?	vf  Continuing with good quotes.	wf  =There was an unknown error while retrieving the price quotes.	xg  first	yg  second	zg  third	{g  assq-ref	|g  gnc:time-no-zone	}g  currency	~g  string?	g  gnc-commodity-table-lookup f  ISO4217 g  
string-upcase g  gnc-pricedb-get-db g  gnc-commodity-get-printname g  or-map g  last g  nav g  price   f  last f  nav f  unknown g  double-to-gnc-numeric g  GNC-DENOM-AUTO g  GNC-DENOM-SIGFIGS g  
GNC-RND-ROUND g  gnc-parse-time-to-time64 f  %Y-%m-%d %H:%M:%S g  
gnc:get-today g  gnc-pricedb-lookup-day g  gnc-price-create g  gnc-price-begin-edit g  gnc-price-set-commodity g  gnc-price-set-currency g  gnc-price-set-time g  gnc-price-set-source g  PRICE-SOURCE-FQ g  gnc-price-set-typestr g  gnc-price-set-value g  gnc-price-commit-edit g  gnc-price-get-source g  any f  (Unable to create prices for these items: f  Add remaining good quotes? f  Adding remaining good quotes. g  gnc-pricedb-add-price g  gnc-price-unref g  format f  Found Finance::Quote version ~A g  gnc:msg f  Found Finance::Quote version  g  !gnc-quote-source-set-fq-installedC 5      hB  7  ]4	
5 4
 >  "  G   4       h   B   ] 45 6   :       g  filenamef  price-quotes.scm
	
 		
   C>  "  G  4    h   B   ] 45 6   :       g  filenamef  price-quotes.scm
	
 		
   C>  "  G  4  >  "  G  4# >  "  G  4& >  "  G  4* >  "  G  4+i,
>  "  G  4+i-
>  "  G  .      hX     ]4L  54L 54LL5L$   $  
LL6LL 6$  CLL6       g  item
		W g  key			W g  val			W g  existing-val			W  g  filenamef  price-quotes.scm
	0			1				1			2			1			3			1		%	5		+	9	
	6	:	 	8	:		C	;	 	E	;		K	7	
	W	7	! 		W  g  nameg  handle-item C    h(      ]4O  >  "  G  C       g  lst
		( g  hash		( g  getkey			( g  getval			( g  hashref			( g  hashset			( g  list-duplicates?			(  g  filenamef  price-quotes.scm
	#
		=	 		(	  g  nameg  item-list->hash! C/R40i41i5 253R43567        h(      ] 45$  C4 5N C             g  filenamef  price-quotes.scm
	I			J		
	J			K			L			L	&		L			K		 	K	
 
		"
  g  nameg  
start-program C8     h   l   ] M (  CM 6       d       g  filenamef  price-quotes.scm
	[			\			]	
 		
  g  nameg  kill-program C43567      h(      ] 45$  C4 5N C             g  filenamef  price-quotes.scm
	I			J		
	J			K			L			L	&		L			K		 	K	
 
		"
  g  nameg  
start-program C9:;<=>   h(   k   ] 4M5N 4M >  "  G  M C      c       g  filenamef  price-quotes.scm
	T	
		U			U			V			V			V	 		"
   C   h   h   - 1 3  C    `       g  key
			 g  args			  g  filenamef  price-quotes.scm
	X	
 			
   C8  h   l   ] M (  CM 6       d       g  filenamef  price-quotes.scm
	[			\			]	
 		
  g  nameg  kill-program C8      h   l   ] M (  CM 6       d       g  filenamef  price-quotes.scm
	[			\			]	
 		
  g  nameg  kill-program C h      ]HH  O  O 4 O >   "  G  VJ (  "  &H44J 55K4O >  X4	 O >   "  G  CX4
 O >   "  G  F            g  program
	  g  
from-child	  g  results		8	]  g  filenamef  price-quotes.scm
	E
		F			F			_		2	O		8	P	
	;	Q		>	Q	+	G	Q		I	Q		J	R		_	_	 
	 
  g  nameg  gnc:fq-check-sources C?R40i41i5 @5AR4A567   h(      ] 45$  C4 5N C             g  filenamef  price-quotes.scm
 		 		
 		 		 		 	%	 		 		  	
 
		"
  g  nameg  start-quoter C8     h   n   ] M (  CM 6       f       g  filenamef  price-quotes.scm
 		 		 	
 		
  g  nameg  kill-quoter C4A567    h(      ] 45$  C4 5N C             g  filenamef  price-quotes.scm
 		 		
 		 		 		 	%	 		 		  	
 
		"
  g  nameg  start-quoter CB:9C;=DEF.G       h   ]   ] M 6      U       g  x
		
  g  filenamef  price-quotes.scm
 		
 	( 		
   CHI<>        h   	  ] 4L>  "  G  4(M>  "  G  4LM>  "  G  4M>  "  G  4LO L>  "  G  4)M>  "  G  4M>  "  G  4M>  "  G  4	M 5N4
M>  "  G  MC         g  filenamef  price-quotes.scm
 		 		 		 		 		+ 		0 		7 		@ 		D 		K 		T 		` 	<	e 		n 	  	  	  	   	  	  	  	 	 
   C     h   i   - 1 3  C    a       g  key
			 g  args			  g  filenamef  price-quotes.scm
 	 			
   C    h   c   ]L LL O 6  [       g  request
		  g  filenamef  price-quotes.scm
 	
	 	 		   C8       h   n   ] M (  CM 6       f       g  filenamef  price-quotes.scm
 		 		 	
 		
  g  nameg  kill-quoter C8    h   n   ] M (  CM 6       f       g  filenamef  price-quotes.scm
 		 		 	
 		
  g  nameg  kill-quoter C       h   Y  ]!HHHO O 4O >   "  G  VJ(  "  6H44J
55K44J55K4O  >  X4	O >   "  G  CX4
O >   "  G  F  Q      g  requests
	  g  quoter	  g  to-child		  g  
from-child		  g  results		;	p  g  filenamef  price-quotes.scm
	s
	 		 		 		5 		; 	
	> 		A 	*	J 		L 		M 		P 	+	Y 		[ 		\ 		r 	 	   g  nameg  gnc:fq-get-quotes CJRKLMN       h      ]4  5C      y       g  a
		  g  filenamef  price-quotes.scm
 		 	,	 	A	 	J	 	,	 	' 		   COPQ     h      ]4 5C  {       g  cmd
		  g  filenamef  price-quotes.scm
 	+	 	2	 	<	
 	F	 	2	
 	- 		   CR/STUVWX   h      ] C            g  key
		 g  value		 g  prior-result			  g  filenamef  price-quotes.scm
 		 		
 	 			   CC       h   q   ]   C    i       g  cmd
		  g  filenamef  price-quotes.scm
 		 	&	 	6	 	0 		   CQCY    h       ]L 4 54 5 C             g  quote-item-info
		  g  filenamef  price-quotes.scm
	
				
		
	1	

					1					 
		   CY        h   t   ] 6       l       g  quote-item-info
			  g  filenamef  price-quotes.scm
			.			 			   C h0      ] $   O  6 4 5 C           g  fq-call-data
		,  g  filenamef  price-quotes.scm
 					#						
							%		'		(			+
	 		,  g  nameg  fq-call-data->fq-calls CJZ[       h      ] $   CC            g  
alist-item
		  g  filenamef  price-quotes.scm
1		2			2		3	#	3	6	3		3	 		   C  h`   N  ]"   M N C$  ?(  "  $  45"  $     M N C""    F      g  	call-data
		\ g  call-result		\  g  filenamef  price-quotes.scm
*		
<	!	<		<		;		-		-		-		-		'/		(/		,-		-0		44		60		?-		B7		E8		J9		M7		P7		R6	 		\	  g  nameg  process-a-quote C\.. h      ] M N C  x       g  	call-item
		  g  filenamef  price-quotes.scm
R	
	S	0	S	'	
S	!	S	 		   C\.=]^ h8      ]4L>  "  G  4 >  "  G  L L 6             g  result-subitem
		2  g  filenamef  price-quotes.scm
H		I		I	!	I		J		J	!	"J		2K	 			2   C     h8      ]"  L  6$  $  L  O 6""           g  call-data-item
		4 g  call-result-item		4  g  filenamef  price-quotes.scm
E	
	M		F		F		F		F	8	F	1	F		,G	 
		4	   C      hH     ]"  L O  6$  (4 545$  LO  6""        g  	call-data
		G g  call-result		G  g  filenamef  price-quotes.scm
?		T	
	Q		@		@		@		A		#A	,	*A	'	+A		/@		;N	
	?D	 		G	  g  nameg  process-call-result-pair C_`0abY  h(      ] $  C4 54 56              g  cq-pair
		!  g  filenamef  price-quotes.scm
			!					"		?		"		"		"		>		"	!	! 		!   CcdefghijklmnoEepHqrs        hP      ]445 >  "  G  4 >  "  G  4 >  "  G  4L 5 6       g  p
		P  g  filenamef  price-quotes.scm
						
								.		2		9		D		J	7	L		P	 		P   CtEepHqrsu 	h      ]445 >  "  G  4 >  "  G  4 >  "  G  44L 5 >  "  G  4 >  "  G  45 6            g  p
		{  g  filenamef  price-quotes.scm
						
								.		2		9		B		E		K	6	M		T		]		q		u		w		{	 		{   CEepHqrsv 	    h     ]445 >  "  G  4 >  "  G  4 >  "  G  44L 5 >  "  G  4 >  "  G  445 >  "  G   6         g  p
	   g  filenamef  price-quotes.scm
!		"		"		
"		"		"		#		.$		2$		9$		B%		E%		K%	1	M%		T%		]&		o'		r'		v'		x'		'	 (	 	    Cwxyz{|}K~{       h       ]	4L  5$  
N NCC        g  	price-sym
		 g  p		  g  filenamef  price-quotes.scm
z		{		{		|		}		~	 		   C0bY -   h    ]Y4 54 >  "  G  4 545HHH454L 5$  $45$  4	
455"  "  4L 5	H
4
>  "  G  4O >  "  G  J$  "  $  "  $  "  KJ$  4J4		55K"   J$  J45
K"  45 K"  4 56$ $ vJ$ lJ$ bJ$ X4!	J5K
J
(  4"L 5$  4#>  "  G  4$>  "  G  4%>  "  G  4&J>  "  G  4'(>  "  G  4)J>  "  G  4*J>  "  G  4+>  "  G  C4 564,J
5($  v4#J
>  "  G  4&J
J>  "  G  4'J
(>  "  G  4)J
J>  "  G  4*J
J>  "  G  4+J
>  "  G  CC"w"s"o"k"g           g  triple
	 g  	commodity		 g  
quote-data		$ g  gnc-time		/ g  price		2 g  
price-type		5 g  currency-str		@ g  commodity-table		I g  currency		v g  pricedb			 g  saved-price	
  g  key	   g  timestr	! g  	gnc-price	{1  g  filenamef  price-quotes.scm
,		g			g		h		i		$g		'j		-j	*	/j		/g		8m		>m	.	@m		@g		Cn		Ig		Qp		Rq		\p		]r		cs	-	dt	-	lr		vg		yu		g	 w	 z	 	 z	 	 	 	 	 	 	 	 	 	 	3	+		
		a	
a	,a	
a	#	
(	.	
8	9	A	
A	M	`	n	t	u	{										(	")	&1	2	;	?	@	R	f	z			 T	   C~EeHqrM~s      h     ]445 >  "  G  4 >  "  G  4 >  "  G  444L 5	5 >  "  G  4 >  "  G  4
5 6            g  p
	   g  filenamef  price-quotes.scm
5		6		6		
6	 	6		6		7		.8		28		98		B9		E9		H9	*	R9	B	T9		[9		d:		x;		|;	 	~;	 ;	 	    CEeHqrM~s     h     ]445 >  "  G  4 >  "  G  4 >  "  G  444L 5	5 >  "  G  4 >  "  G  44
5 >  "  G   6          g  p
	   g  filenamef  price-quotes.scm
>		?		?		
?		?		?		@		.A		2A		9A		BB		EB		HB	)	RB	A	TB		[B		dC		vD		yD		}D		D	 D	 E	 	    C~    h   f   ]4 5C     ^       g  x
		  g  filenamef  price-quotes.scm
I	#	I	4	
I	/ 		   C        h8   s   ] $  (4L  >  "  G  4 >  "  G  CC      k       g  price
		2  g  filenamef  price-quotes.scm
									 		2   C 5 h  	  ]R4545H44>  G K54	5"  94J	
>  "  G  4
45455"  J(  (  "  ""  "$  4
45?"  $  45"  $  {$  nHO Q $  L$  @4545$  (4O >  "  G  4J5"  "  "  "  "  $  
45"  $  
4	5"  H&  DK45 $  4 45>  "  G  "  445>  "  G  " %&  DK45 $  4 4 5>  "  G  "  44 5>  "  G  " 4!"5$  FK45 $  4 4#5>  "  G  "  44#5$>  "  G  " 4!%5$  FK45 $  4 4&5>  "  G  "  44&5$>  "  G  " 4$  $  "  45 $   4 4 5>  "  G  K"  $  (  "  45 $  _"  %4 4'(O 5>  "  G  K"  2$  ((  ""  4) 4'*O 55K"  ""  44'+O 5>  "  G  "  44 5>  "  G  K"  BK45 $  4 4,5>  "  G  "  44,5$>  "  G  J$  4-O 5	4./	5$  C45 $  4) 4'0	O 55K"  44'1	O 5>  "  G  "   J$  !42	5
4354O 
6CC 	      g  window
	 g  book	 g  ct			  g  big-list		  g  commodity-list		  g  a		)	< g  b		)	< g  
currency-list		>  g  
quote-hash		G  g  fq-call-data	  g  fq-calls	  g  
fq-results	  g  result-list	 [ g  process-a-quote	 X g  commod-tz-quote-triples	e g  problem-syms	{ g  ok-syms	 g  keep-going?	 g  prices		 g  prices	
{ g  pricedb	  g  filenamef  price-quotes.scm
 
	 			 		 		 		 		 	*	, 		4 	+	> 		> 		A 		G 		N 		k 		n 	
	s 		w 	
	x 	
  	  	  	
 	 	 	 	 	 	 	 	# 	 	
 	! 	 	
 (	 (	V	V	W	V	X	X	$X	"V	#Z	
@]	
e	m	
n	{		
					
		
	#	&	#	
	
				
			
		
	#	& 	#	
	
			 	
-	1	5	9	<	=	
E	F	
K	O	Q	V	
c	
f	j	l	n	/s	
						
		
				
	
				V	
			 	 	)				
		
			
'	,	1	A	L	P		
\		e	k
	x	z
		
 		
								
		
				
	
				X	
*	
,	,	/	)/	*0	20	33	94	F3	H1	M<	P=	`<	rG	sH	"{H	~			 		  g  nameg  gnc:book-add-quotes CR?H      hX   
  ]45   $  B4 >  "  G  4>   "  G  4 >  "  G   6C          g  sources
		T  g  filenamef  price-quotes.scm
Z
	[		[		\		\		^		^		^	3	^		'_		7`	
	;`		>`	3	C`	
	Pa	-	Ra	
 		T
  g  nameg   gnc:price-quotes-install-sources CRC      /      g  m
	
	$  g  filenamef  price-quotes.scm		
	%	
 	
	
-	
B	
W	
l	 
r	 	x	 
	!
	!		!
N	#
O	C	T	C	\	C	'^	C	a	B

	E

	q	
	q	
	q	'
	q	
	p
	s
A` 
BZ
 	B
   C6 